﻿--
-- Specialization for Cutter  wg. klappbar und Sanftan - und Auslauf der rolls
--
-- @author  	Manuel Leithner
-- @version 	v1.0
-- @date  		02/11/11
-- @history:	v1.0 - Initial version
--
-- @edit for deutz foldablecutter 7545RTS by usxi7sd 11/2013

deutzcutter = {};

function deutzcutter.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Foldable, specializations);
end;

function deutzcutter:load(xmlFile)	
	self.deutzcutter = {};
	self.deutzcutter.speedScaleTime = 5000;
	self.deutzcutter.speed = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.deutzcutter#speed"), 11);
	self.deutzcutter.rollSpeedBackup = self.rollNodes[1].speed;
	for _, rollNode in pairs(self.rollNodes) do
		rollNode.backup = rollNode.speed;
		rollNode.speed = 0;
	end;	
	self.startThreshingBackup = nil;	
	self.printFoldingError = 0;
	self.printTurnOnError = 0;
end;

function deutzcutter:delete()
end;
function deutzcutter:readStream(streamId, connection)
end;
function deutzcutter:writeStream(streamId, connection)
end;
function deutzcutter:mouseEvent(posX, posY, isDown, isUp, button)
end;
function deutzcutter:keyEvent(unicode, sym, modifier, isDown)
end;

function deutzcutter:update(dt)
	Utils.setEmittingState(self.threshingParticleSystems, (self.reelStarted and self.lastCutterAreaBiggerZero));
	
	if self:getIsActive() and self.reelStarted then	
		local percent = math.max(0.85, math.min((self.lastSpeed*3600) / self.deutzcutter.speed, 1.5));
	
		for _, rollNode in pairs(self.rollNodes) do
			local rollSpeed = Utils.getMovedLimitedValues({rollNode.speed}, {rollNode.backup * percent}, {0}, 1, self.deutzcutter.speedScaleTime, dt, false);
			rollNode.speed = rollSpeed[1];
		end;
	else
		if self.rollNodes[1].speed ~= 0 then
			local percent = math.max(0.85, math.min((self.lastSpeed*3600) / self.deutzcutter.speed, 1.5));
		
			for _, rollNode in pairs(self.rollNodes) do
				local rollSpeed = Utils.getMovedLimitedValues({rollNode.speed}, {rollNode.backup * percent}, {0}, 1, self.deutzcutter.speedScaleTime*1.5, dt, true);
				rollNode.speed = rollSpeed[1];
				rotate(rollNode.node, -dt*rollNode.speed, 0, 0);
			end;
		end;
	end;	
	
	if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) and self.reelStarted and self.foldAnimTime < 1 then
		self.printFoldingError = self.time + 1800;
		self:setFoldDirection(1, false);
	end;
end;

function deutzcutter:updateTick(dt)
end;

function deutzcutter:draw()	
	if self.printFoldingError > self.time then
		g_currentMission:addWarning(g_i18n:getText("TURNOFF_CHOPPER_FIRST"), 0.018, 0.033);		
	end;
	if self.printTurnOnError > self.time then
		g_currentMission:addWarning(g_i18n:getText("UNFOLD_CHOPPER_FIRST"), 0.018, 0.033);
	end;
end;

function deutzcutter:onAttach(attacherVehicle)
	self.combine = attacherVehicle;
	if self.combine.threshingStartSound ~= nil then
		self.startThreshingBackup = self.combine.threshingStartSound;
	end;
end;

function deutzcutter:onDetach()	
	if self.startThreshingBackup ~= nil then
		self.combine.threshingStartSound = self.startThreshingBackup;
	end;	
	self.combine = nil;
end; 

function deutzcutter:onStartReel()
	if self.foldAnimTime < 1 then
		if self.combine.isAIThreshing then
			self.combine:stopAIThreshing(true);
		else
			self.combine:setIsThreshing(false, true);
		end;
		self.printTurnOnError = self.time + 1800;
		self.combine.threshingStartSound = nil;
	else
		self.combine.threshingStartSound = self.startThreshingBackup;
	end;
end;

function deutzcutter:setFoldDirection(direction, noEventSend)
	if self.reelStarted and direction == -1 then
		self.printFoldingError = self.time + 1800;
		self:setFoldDirection(1, false);
	end;
	--if self.reelStarted and self.foldAnimTime < 1 then
		--self.printFoldingError = self.time + 1800;
		--self:setFoldDirection(1, false);		
	--end;
end;